import { IdlField, IdlInstructionArg, IdlType, PrimaryTypeMap, TypeMappedSerdeField } from './types';
import { BeetTypeMapKey } from '@metaplex-foundation/beet';
import { BeetSolanaTypeMapKey } from '@metaplex-foundation/beet-solana';
import { SerdePackage } from './serdes';
export declare function resolveSerdeAlias(ty: string): string;
export declare type ForceFixable = (ty: IdlType) => boolean;
export declare const FORCE_FIXABLE_NEVER: ForceFixable;
export declare class TypeMapper {
    private readonly forceFixable;
    private readonly userDefinedEnums;
    private readonly primaryTypeMap;
    readonly serdePackagesUsed: Set<SerdePackage>;
    readonly scalarEnumsUsed: Map<string, string[]>;
    usedFixableSerde: boolean;
    constructor(forceFixable?: ForceFixable, userDefinedEnums?: Set<string>, primaryTypeMap?: PrimaryTypeMap);
    clearUsages(): void;
    private updateUsedFixableSerde;
    private updateScalarEnumsUsed;
    private mapPrimitiveType;
    private mapOptionType;
    private mapVecType;
    private mapArrayType;
    private mapDefinedType;
    private mapEnumType;
    map(ty: IdlType, name?: string): string;
    private mapPrimitiveSerde;
    private mapStringSerde;
    private mapOptionSerde;
    private mapVecSerde;
    private mapArraySerde;
    private mapDefinedSerde;
    private mapEnumSerde;
    mapSerde(ty: IdlType, name?: string): string;
    mapSerdeField: (field: IdlField | IdlInstructionArg) => TypeMappedSerdeField;
    mapSerdeFields(fields: (IdlField | IdlInstructionArg)[]): TypeMappedSerdeField[];
    importsForSerdePackagesUsed(forcePackages?: Set<SerdePackage>): string[];
    assertBeetSupported(serde: IdlType, context: string): asserts serde is BeetTypeMapKey | BeetSolanaTypeMapKey;
    static defaultPrimaryTypeMap: PrimaryTypeMap;
}
